==> haskell-persistent-template-2.5.2-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.5.2
id: persistent-template-2.5.2-LGZpRcJ9B1oVaV3mrctnN
key: persistent-template-2.5.2-LGZpRcJ9B1oVaV3mrctnN
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
abi: 59de9cdd0a41a1cdff0813dcd8489f85
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/persistent-template-2.5.2
hs-libraries: HSpersistent-template-2.5.2-LGZpRcJ9B1oVaV3mrctnN
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
    aeson-compat-0.3.6-BgkQr6SS9HzHuI3hlz91Mo base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 ghc-prim-0.5.0.0
    http-api-data-0.3.6-J82vsTCH5jB5BG5Viozokg
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.22-8PB2t4Dw3Q1JAypjoMUGjR
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    persistent-2.6.1-Bj2UKzWMyMVJmynx4AHWe9
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-template-2.5.2-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.5.2
id: persistent-template-2.5.2-AE6Vo6Oc6GH8RCtKwlc1qH
key: persistent-template-2.5.2-AE6Vo6Oc6GH8RCtKwlc1qH
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
abi: 74fefe54504a09a3a7f381e60edfd298
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/persistent-template-2.5.2
hs-libraries: HSpersistent-template-2.5.2-AE6Vo6Oc6GH8RCtKwlc1qH
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
    aeson-compat-0.3.6-BgkQr6SS9HzHuI3hlz91Mo base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 ghc-prim-0.5.0.0
    http-api-data-0.3.6-LHgMdWokLE6LSKp0FY3jjp
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.22-8PB2t4Dw3Q1JAypjoMUGjR
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    persistent-2.6.1-jm42Lk1gnI6NIlUTVhrmd
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
